@@ -1,7 +1,7 @@
 use bstr::ByteSlice;
 
 use crate::config::{Config, Delimiter};
-use crate::select::SelectColumns;
+use crate::select::SelectedColumns;
 use crate::util;
 use crate::CliError;
 use crate::CliResult;
@@ -47,7 +47,7 @@ John,yellow
 Mary,red
 
 Note that the file can be exploded on multiple well-aligned columns (that
-is to say selected cells must all be splitted into a same number of values).
+is to say selected cells must all be split into a same number of values).
 
 Finally, if you need more complex stuff that splitting cells by a separator,
 check out the `flatmap` command instead.
@@ -78,7 +78,7 @@ Common options:
 
 #[derive(Deserialize)]
 struct Args {
-    arg_columns: SelectColumns,
+    arg_columns: SelectedColumns,
     arg_input: Option<String>,
     flag_sep: String,
     flag_singularize: bool,
@@ -101,8 +101,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .no_headers(args.flag_no_headers)
         .select(args.arg_columns);
 
-    let mut rdr = rconfig.reader()?;
-    let mut wtr = Config::new(&args.flag_output).writer()?;
+    let mut rdr = rconfig.simd_reader()?;
+    let mut wtr = Config::new(&args.flag_output).simd_writer()?;
 
     let mut headers = rdr.byte_headers()?.clone();
     let sel = rconfig.selection(&headers)?;
@@ -121,7 +121,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         if new_names.len() != sel.len() {
             Err(format!(
-                "Renamed columns alignement error. Expected {} names and got {}.",
+                "Renamed columns alignment error. Expected {} names and got {}.",
                 sel.len(),
                 new_names.len(),
             ))?;
@@ -152,8 +152,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         wtr.write_byte_record(&headers)?;
     }
 
-    let mut record = csv::ByteRecord::new();
-    let mut output_record = csv::ByteRecord::new();
+    let mut record = simd_csv::ByteRecord::new();
+    let mut output_record = simd_csv::ByteRecord::new();
 
     'main: while rdr.read_byte_record(&mut record)? {
         let mut splits: Vec<Vec<&[u8]>> = Vec::with_capacity(sel.len());
@@ -168,7 +168,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         if splits.iter().skip(1).any(|s| s.len() != splits[0].len()) {
             return Err(CliError::Other(
-                "inconsistent exploded length accross columns.".to_string(),
+                "inconsistent exploded length across columns.".to_string(),
             ));
         }
 
